// Kiosk code.

// We'll need an array of KioskModeInfo instances
// that store a set of distinct queries.
KioskModeInfo[] modes;
// Also, keep track of which mode is currently
// being displayed on the screen.
int current_mode;

// How many seconds to spend on each screen.  Currently
// set to 10 so that you don't have to wait forever to
// make sure your sketch works.  In reality, it would
// probably be more like 30 seconds or a minute.
float seconds_per_mode = 10;
// The time of the previous screen change.
int last_mode_switch_time;

// This function checks whether we need to cycle to the
// next kiosk screen.  Called at the beginning of every
// draw().
void updateMode()
{
  // How long has it been since the screen changed?
  float secs = (millis() - last_mode_switch_time) / 1000.0;
  // If it's long enough, it's time to change.
  if ( secs > seconds_per_mode ) {
    // Do that by updating the current mode, and by 
    // resetting the time of the last switch to the
    // current time.
    current_mode = (current_mode + 1) % modes.length;
    last_mode_switch_time = millis();
    
    // TODO -- This is a place where you *might* need to
    // insert code, if there's anything you want to do once
    // when you switch screens.  But it's not required --
    // it's quite possible to finish the assignment without
    // adding anything here.
  }
}

void setup()
{
  size( 600, 400 );
  current_mode = 0;
  last_mode_switch_time = millis();

  // TODO -- you'll definitely need to update this.  Create
  // an array of size at least two, and set each element of the
  // array to a distinct KioskModeInfo instance that queries an
  // interesting piece of information.
  modes = new KioskModeInfo[ 1 ];
  modes[0] = new KioskModeInfo( "TEST", "" );
  
  // Do any other setup that you want.  Here I'm setting a big
  // font for my one test display.  Feel free to change this or
  // remove it.
  textFont( createFont( "Helvetica", 48 ) );
  textAlign( CENTER );
}

void draw()
{
  // Check to see if we need to change to the next screen.
  updateMode();
  // Whatever the current mode is, retrieve its JSON object.
  JSONObject obj = modes[current_mode].getData();

  if ( current_mode == 0 ) {
    // TODO -- this is all for demonstration purposes.
    // change it into anything you want, as long as it
    // fulfills the minimum requirements of the assignment.
    background( 0 );
    int ivalue = obj.getInt( "an_integer" );
    text( "The int: " + ivalue, width/2, 100 );
    float fvalue = obj.getFloat( "a_float" );
    text( "The float: " + fvalue, width/2, 200 );
    JSONArray arr = obj.getJSONArray( "an_array" );
    String msg = "[";
    for( int idx = 0; idx < arr.size(); ++idx ) {
      if( idx > 0 ) {
        msg = msg + ", ";
      }
      msg = msg + arr.getInt( idx );
    }
    msg = msg + "]";
    text( msg, width/2, 300 );
  }
  // TODO -- you'll probably want more cases here to
  // handle the other possible values of current_mode,
  // based on how many modes you have.

  // Don't touch this stuff -- it draws a little countdown
  // timer in the bottom-right corner of the sketch to show
  // you how long you have to read what's there.
  
  pushStyle();
  float pct = float(millis() - last_mode_switch_time) / (seconds_per_mode*1000);
  noStroke();
  fill( 255, 100, 100 );
  arc( width - 30, height - 30, 40, 40, -HALF_PI, -HALF_PI + TWO_PI*pct, PIE);
  popStyle();
}
